@@ -10,6 +10,7 @@ from instagrapi.mixins.clip import DownloadClipMixin, UploadClipMixin
 from instagrapi.mixins.collection import CollectionMixin
 from instagrapi.mixins.comment import CommentMixin
 from instagrapi.mixins.direct import DirectMixin
+from instagrapi.mixins.fbsearch import FbSearchMixin
 from instagrapi.mixins.hashtag import HashtagMixin
 from instagrapi.mixins.igtv import DownloadIGTVMixin, UploadIGTVMixin
 from instagrapi.mixins.insights import InsightsMixin
@@ -37,6 +38,7 @@ class Client(
     TopSearchesPublicMixin,
     ProfilePublicMixin,
     LoginMixin,
+    FbSearchMixin,
     DownloadPhotoMixin,
     UploadPhotoMixin,
     DownloadVideoMixin,
