@@ -75,6 +75,7 @@ class UploadIGTVMixin:
         usertags: List[Usertag] = [],
         location: Location = None,
         configure_timeout: int = 10,
+        extra_data: Dict[str, str] = {},
     ) -> Media:
         """
         Upload IGTV to Instagram
@@ -95,6 +96,8 @@ class UploadIGTVMixin:
             Location tag for this upload, default is none
         configure_timeout: int
             Timeout between attempt to configure media (set caption, etc), default is 10
+        extra_data: Dict[str, str], optional
+            Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
         -------
@@ -177,6 +180,7 @@ class UploadIGTVMixin:
                     caption,
                     usertags,
                     location,
+                    extra_data=extra_data
                 )
             except ClientError as e:
                 if "Transcode not finished yet" in str(e):
@@ -205,6 +209,7 @@ class UploadIGTVMixin:
         caption: str,
         usertags: List[Usertag] = [],
         location: Location = None,
+        extra_data: Dict[str, str] = {},
     ) -> Dict:
         """
         Post Configure IGTV (send caption, thumbnail and more to Instagram)
@@ -229,6 +234,8 @@ class UploadIGTVMixin:
             List of users to be tagged on this upload, default is empty list.
         location: Location, optional
             Location tag for this upload, default is None
+        extra_data: Dict[str, str], optional
+            Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
         -------
@@ -259,6 +266,7 @@ class UploadIGTVMixin:
             "extra": {"source_width": width, "source_height": height},
             "audio_muted": False,
             "poster_frame_index": 70,
+            **extra_data
         }
         return self.private_request(
             "media/configure_to_igtv/?video=1",
